@@ -32,10 +32,10 @@ typedef struct GNUTLS_COMP_HANDLE_STRUCT {
 	CompressionMethod algo;
 } *GNUTLS_COMP_HANDLE;
 
-GNUTLS_COMP_HANDLE gnutls_comp_init( CompressionMethod, int d);
-void gnutls_comp_deinit(GNUTLS_COMP_HANDLE handle, int d);
+GNUTLS_COMP_HANDLE _gnutls_comp_init( CompressionMethod, int d);
+void _gnutls_comp_deinit(GNUTLS_COMP_HANDLE handle, int d);
 
-int gnutls_decompress( GNUTLS_COMP_HANDLE handle, char* compressed, int compressed_size, char** plain, int max_record_size);
-int gnutls_compress( GNUTLS_COMP_HANDLE, char* plain, int plain_size, char** compressed, int max_comp_size);
+int _gnutls_decompress( GNUTLS_COMP_HANDLE handle, char* compressed, int compressed_size, char** plain, int max_record_size);
+int _gnutls_compress( GNUTLS_COMP_HANDLE, char* plain, int plain_size, char** compressed, int max_comp_size);
 
 #endif
