@@ -45,23 +45,23 @@ typedef GNUTLS_MAC_HANDLE GNUTLS_HASH_HANDLE;
 #define GNUTLS_HASH_FAILED NULL
 #define GNUTLS_MAC_FAILED NULL
 
-GNUTLS_MAC_HANDLE gnutls_hmac_init( MACAlgorithm algorithm, void* key, int keylen);
-int gnutls_hmac_get_algo_len(MACAlgorithm algorithm);
-int gnutls_hmac(GNUTLS_MAC_HANDLE handle, const void* text, int textlen);
-void gnutls_hmac_deinit( GNUTLS_MAC_HANDLE handle, void* digest);
+GNUTLS_MAC_HANDLE _gnutls_hmac_init( MACAlgorithm algorithm, void* key, int keylen);
+int _gnutls_hmac_get_algo_len(MACAlgorithm algorithm);
+int _gnutls_hmac(GNUTLS_MAC_HANDLE handle, const void* text, int textlen);
+void _gnutls_hmac_deinit( GNUTLS_MAC_HANDLE handle, void* digest);
 
-GNUTLS_MAC_HANDLE gnutls_mac_init_ssl3( MACAlgorithm algorithm, void* key, int keylen);
-void gnutls_mac_deinit_ssl3( GNUTLS_MAC_HANDLE handle, void* digest);
+GNUTLS_MAC_HANDLE _gnutls_mac_init_ssl3( MACAlgorithm algorithm, void* key, int keylen);
+void _gnutls_mac_deinit_ssl3( GNUTLS_MAC_HANDLE handle, void* digest);
 
-GNUTLS_HASH_HANDLE gnutls_hash_init(MACAlgorithm algorithm);
-int gnutls_hash_get_algo_len(MACAlgorithm algorithm);
-int gnutls_hash(GNUTLS_HASH_HANDLE handle, const void* text, int textlen);
-void gnutls_hash_deinit(GNUTLS_HASH_HANDLE handle, void* digest);
+GNUTLS_HASH_HANDLE _gnutls_hash_init(MACAlgorithm algorithm);
+int _gnutls_hash_get_algo_len(MACAlgorithm algorithm);
+int _gnutls_hash(GNUTLS_HASH_HANDLE handle, const void* text, int textlen);
+void _gnutls_hash_deinit(GNUTLS_HASH_HANDLE handle, void* digest);
 
-int gnutls_ssl3_generate_random(void *secret, int secret_len, void *random, int random_len, int bytes, opaque* ret);
+int _gnutls_ssl3_generate_random(void *secret, int secret_len, void *random, int random_len, int bytes, opaque* ret);
 
-void gnutls_mac_deinit_ssl3_handshake(GNUTLS_MAC_HANDLE handle, void* digest, opaque* key, uint32 key_size);
+void _gnutls_mac_deinit_ssl3_handshake(GNUTLS_MAC_HANDLE handle, void* digest, opaque* key, uint32 key_size);
 
-GNUTLS_HASH_HANDLE gnutls_hash_copy(GNUTLS_HASH_HANDLE handle);
+GNUTLS_HASH_HANDLE _gnutls_hash_copy(GNUTLS_HASH_HANDLE handle);
 
 #endif /* GNUTLS_HASH_INT_H */
