@@ -28,6 +28,7 @@
 #include <string.h>
 #include <unistd.h>
 #include "../lib/gnutls.h"
+#include "../libextra/gnutls-extra.h"
 #include <sys/time.h>
 #include <signal.h>
 #include <netdb.h>
@@ -162,10 +163,14 @@ int main(int argc, char **argv)
       exit(1);
    }
 
+   if (gnutls_global_init_extra() < 0) {
+      fprintf(stderr, "global state initialization error\n");
+      exit(1);
+   }
 
    /* X509 stuff */
    if (gnutls_certificate_allocate_sc(&xcred) < 0) {	/* space for 2 certificates */
-      fprintf(stderr, "memory error\n");
+      fprintf(stderr, "Certificate allocation memory error\n");
       exit(1);
    }
 
@@ -216,16 +221,14 @@ int main(int argc, char **argv)
    /* SRP stuff */
    if (srp_username!=NULL) {
       if (gnutls_srp_allocate_client_sc(&cred) < 0) {
-         fprintf(stderr, "memory error\n");
-         exit(1);
+         fprintf(stderr, "SRP authentication error\n");
       }
       gnutls_srp_set_client_cred(cred, srp_username, srp_passwd);
    }
    
    /* ANON stuff */
    if (gnutls_anon_allocate_client_sc(&anon_cred) < 0) {
-      fprintf(stderr, "memory error\n");
-      exit(1);
+      fprintf(stderr, "Anonymous authentication error\n");
    }
 
    printf("Resolving '%s'...\n", hostname);
@@ -306,6 +309,8 @@ int main(int argc, char **argv)
 	 return 1;
       } else {
 	 printf("- Handshake was completed\n");
+	 if (gnutls_session_is_resumed( state)!=0)
+	 	printf("*** This is a resumed session\n");
       }
 
       if (i == 1) {		/* resume */
